camelot.camelot.view.elixir_admin

Package camelot :: Package camelot :: Package view :: Module elixir_admin |
[hide private]
[frames] | no frames]

# Module elixir_admin

source code

To Do: rewrite docstring

Admin classes, specify how objects should be rendered in the gui

An admin class has class attributes like 'list_display' which contains the columns that should be displayed in a list view (again, see Django)

So this 'list_display' attribute can be overwritten in the Admin class for each model.

But for the gui generation itself, we don't use the class attributes, but we use methods, like 'getColumns', that way, we can make the gui very specific, on the context

Classes | [hide private]
| EntityAdmin

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.elixir_admin')`
| _ = `lambda x:`